import request from '@/utils/request'
import Qs from 'qs'
import { parseTime } from '@/utils/common'

/**
 * 1. 列表查询
 * 2. 查询详细信息
 * 3. 新增
 * 4. 修改
 * 5. 逻辑删除
 * 6. 导出
 *
 */

// 1. 查询活动列表
export function listCmsActivity(query) {
  return request({
    url: '/cmsActivity/queryCmsActivityByPagination',
    method: 'get',
    params: query
  })
}

// 2. 查询活动详细信息
export function getCmsActivity(businessId) {
  return request({
    url: '/cmsActivity/detail/' + businessId,
    method: 'get'
  })
}

// 3. 新增活动
export function addCmsActivity(data) {
  data = Qs.stringify(data)
  return request({
    url: '/cmsActivity/add',
    method: 'post',
    data: data
  })
}

// 4. 修改活动
export function updateCmsActivity(data) {
  const businessId = data.businessId
  data = Qs.stringify(data)
  return request({
    url: '/cmsActivity/update/' + businessId,
    method: 'post',
    data
  })
}

// 5. 逻辑删除活动
export function delCmsActivity(businessId) {
  return request({
    url: '/cmsActivity/delete/' + businessId,
    method: 'delete'
  })
}

// 6. 导出活动
export function exportCmsActivity(query) {
  return request({
    url: '/cmsActivity/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}
// 7. 修改活动状态
export function updateStatus(data) {
  const businessId = data.businessId
  data = Qs.stringify(data)
  return request({
    url: '/cmsActivity/updateStatus/' + businessId,
    method: 'post',
    data: data
  })
}
// 7. 修改活动发布状态
export function updatePushStatus(data) {
  return request({
    url: '/cmsActivity/pushActivityInfo',
    method: 'put',
    params: { businessId: data.businessId, status: data.publishStatus }
  })
}
