import request from '@/utils/request'
import Qs from 'qs'

/**
* 1. 列表查询
* 2. 查询详细信息
* 3. 新增
* 4. 修改
* 5. 逻辑删除
* 6. 导出
*
*/

// 1. 查询订单信息表列表
export function listCmsOrder(query) {
  return request({
    url: '/cmsOrder/list',
    method: 'get',
    params: query
  })
}

// 2. 查询订单信息表详细信息
export function getCmsOrder(businessId) {
  return request({
    url: '/cmsOrder/detail/' + businessId,
    method: 'get'
  })
}

// 3. 新增订单信息表
export function addCmsOrder(data) {
  data = Qs.stringify(data)
  return request({
    url: '/cmsOrder/add',
    method: 'post',
    data: data
  })
}

// 4. 修改订单信息表
export function updateCmsOrder(data) {
  const businessId = data.businessId
  data = Qs.stringify(data)
  return request({
    url: '/cmsOrder/update/' + businessId,
    method: 'put',
    data
  })
}

// 5. 逻辑删除订单信息表
export function delCmsOrder(businessId) {
  return request({
    url: '/cmsOrder/deleteLogical/' + businessId,
    method: 'delete'
  })
}

// 6. 导出订单信息表
export function exportCmsOrder(query) {
  return request({
    url: '/cmsOrder/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}

// 7. 查询异常订单信息表列表
export function listExceptionCmsOrder(query) {
  return request({
    url: '/cmsOrder/selectErrorOrderByPagination',
    method: 'get',
    params: query
  })
}

// 8.退款补偿
export function refundReimbursement(data) {
  return request({
    url: '/cmsOrder/refundReimbursement',
    method: 'get',
    params: { // 修改为使用params来传递查询参数
      ids: Array.isArray(ids) ? ids.join(',') : ids // 如果ids是数组，则将其转换为逗号分隔的字符串
    }
  })
}
// 9.支付确认
export function payConfirm(data) {
  return request({
    url: '/cmsOrder/order/payConfirm',
    method: 'post',
    headers: {
      'Content-Type': 'application/json'
    },
    data: data
  })
}

// 9.人工退单
export function chargebacks(data) {
  return request({
    url: '/cmsOrder/cancel',
    method: 'post',
    headers: {
      'Content-Type': 'application/json'
    },
    data: data
  })
}

// 9.人工退单
export function refundConfirm(data) {
  return request({
    url: '/cmsOrder/order/refundConfirm',
    method: 'post',
    headers: {
      'Content-Type': 'application/json'
    },
    data: data
  })
}

// 9.异常订单补偿
export function manualCompensateOrder(data) {
  return request({
    url: '/cmsOrder/manualCompensateOrder',
    method: 'post',
    headers: {
      'Content-Type': 'application/json'
    },
    data: data
  })
}
